@@ -4,10 +4,11 @@ use 5.006;
 
 use strict;
 
+use LWP::Protocol::https;
 use LWP::UserAgent;
 use URI::Escape;
 
-our $VERSION = '1.56';
+our $VERSION = '1.57';
 
 my $API_VERSION = join( '/', 'Perl', $VERSION );
 
@@ -26,6 +27,7 @@ sub new {
     }
     my $self = {@_};
     bless $self, $class;
+    $self->{isSecure} = 1 unless exists $self->{isSecure};
     for my $server (@defaultservers) {
         $self->{servers}->[$i] = $server;
         $i++;
@@ -138,15 +140,13 @@ sub querySingleServer {
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Business::MaxMind::HTTPBase - Base class for accessing HTTP web services
 
 =head1 VERSION
 
-version 1.56
+version 1.57
 
 =head1 DESCRIPTION
 
@@ -204,7 +204,7 @@ Frank Mather <frank@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by MaxMind, Inc..
+This software is Copyright (c) 2015 by MaxMind, Inc..
 
 This is free software, licensed under:
 
